# unpack_module_source():
# we check if we should build a given package
# if so, we unpack sources and add entry to config
# %1 - source number
# %2 - subpackage name

%global unpack_module_source() \
%%if %%{with %%2}\
%setup -q -D -T -a %%1 -n kadu-%{version}/plugins\
sed -e '2a %2' -i ../Plugins.cmake\
%%endif\
%nil

# module_files():
# both internal and external modules have at least their .so, .ui,
# .desc and .qm files. In order to simplify things, this macro 
# creates a simple %files section
# %1 - module/subpackage name
# if parameter -d is specified, module owns its data dir
# 
# all modules have very similar directory and files structure, so
# this macro is created to make it possible to simplify %files
# sections. All modules have .desc and .so files, a lot of them
# has configurations and translations or data dirs. We use 
# respectively -c, -t and -d parameters to know which files
# a module owns.

%global module_files(d,c) \
%find_lang %%1 %%1.files --with-qt || :\
echo %{_libdir}/kadu/plugins/lib%%{1}.so >> %%1.files\
echo %{_datadir}/kadu/plugins/%%1.desc >> %%1.files\
%if "%%{-c}" \
echo %{_datadir}/kadu/plugins/configuration/%%1.ui >> %%1.files\
%endif\
%if "%%{-d}" \
echo %{_datadir}/kadu/plugins/data/%%1 >> %%1.files\
%endif\
%nil

# kadu.spec
# table to make it possible to find out quickly which
# subpackage has which source's number
# LAST NUMBER: 205
# 117 anonymous_check
# 102 globalhotkeys
# 200 import_history
# 205 kadu_completion
# 104 lednotify
# 203 messagessplitter
# 112 mime_tex
# 201 networkping
# 202 nextinfo
# 114 panelkadu
# 204 senthistory


# whether we want to build certain subpackages or not
%bcond_without anonymous_check
%bcond_without globalhotkeys
%bcond_without import_history
%bcond_without kadu_completion
%bcond_without lednotify
%bcond_without messagessplitter
%bcond_without mime_tex
%bcond_without networkping
%bcond_without nextinfo
%bcond_without panelkadu
%bcond_without senthistory


Name:		kadu
Version:	0.12.2
Release:	2%{?dist}
Summary:	An Gadu-Gadu client for online messaging
Summary(pl):	Klient Gadu-Gadu
Group:		Applications/Internet
License:	GPLv2+
URL:		http://www.kadu.net
Source0:	http://download.kadu.im/stable/%{name}-%{version}.tar.bz2

# external modules:
%if %{with anonymous_check}
Source117:	http://download.kadu.im/external-plugins/anonymous_check/anonymous_check-0.11.0-1.tar.bz2
%endif
%if %{with globalhotkeys}
Source102:	http://ultr.pl/kadu/globalhotkeys-0.12-32.tar.gz
%endif
%if %{with import_history}
Source200:	http://download.kadu.im/external-plugins/import_history/import_history-0.12.0.tar.bz2
%endif
%if %{with kadu_completion}
Source205:	http://download.kadu.im/external-plugins/kadu_completion/kadu_completion-0.12.0-1.tar.bz2
%endif
%if %{with lednotify}
Source104:	http://ultr.pl/kadu/lednotify-0.12-33.tar.gz
%endif
%if %{with messagessplitter}
Source203:	http://ultr.pl/kadu/messagessplitter-0.12-5.tar.gz
%endif
%if %{with mime_tex}
Source112:	http://download.kadu.im/external-plugins/mime_tex/mime_tex-0.12.0-2.tar.bz2
%endif
%if %{with networkping}
Source201:	http://ultr.pl/kadu/networkping-0.12-4.tar.gz
%endif
%if %{with nextinfo}
Source202:	http://ultr.pl/kadu/nextinfo-0.12-9.tar.gz
%endif
%if %{with panelkadu}
Source114:	http://ultr.pl/kadu/panelkadu-0.12-10.tar.gz
%endif
%if %{with senthistory}
Source204:	http://ultr.pl/kadu/senthistory-0.12-11.tar.gz
%endif


BuildRequires:	cmake
BuildRequires:	libpng-devel libsndfile-devel openssl-devel
BuildRequires:	qt-devel
BuildRequires:	libgadu-devel >= 1.11.1
BuildRequires:	desktop-file-utils
BuildRequires:	enchant-devel alsa-lib-devel
BuildRequires:	libXScrnSaver-devel
BuildRequires:	qca2-devel
# F-14+: qt-webkit-devel splits from qt-devel
BuildRequires:	qt4-webkit-devel
BuildRequires:	libmpdclient-devel
BuildRequires:	phonon-devel
BuildRequires:	libidn-devel
BuildRequires:	sqlite-devel
#BuildRequires:	iris-devel

%description
Kadu is a dynamically evolving instant messenger compatible with the Gadu-Gadu
protocol.

%description -l pl
Kadu to dynamicznie rozwijający się komunikator internetowy kompatybilny z
protokołem Gadu-Gadu.

%package anonymous_check
Summary:	Automatic lookup of an interlocutor in public directory
Summary(pl):	Automatyczne wyszukiwanie nieznajomych w katalogu
Group:		Applications/Internet
License:	GPLv2+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description anonymous_check
Anonymous_check is a module for Kadu to automatic lookup who is an interlocutor
when (s)he starts talking to you.

%description anonymous_check -l pl
Anonymous_check to moduł dla Kadu, który automatycznie sprawdza dane
w publicznym katalogu nieznajomego, gdy ten zagada.

%package globalhotkeys
Summary:	Global hotkeys support to Kadu
Summary(pl):	Obsługa skrótów globalnych do Kadu
Group:		Applications/Internet
License:	GPLv3+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description globalhotkeys
Globalhotkeys is a module that adds support to global
hotkeys in Kadu.

%description globalhotkeys -l pl
Globalhotkeys to moduł dodający obsługę skrótów globalnych
w Kadu.

%package import_history
Summary:	Imports history from origin GG client.
Summary(pl):	Importuje historię z oryginalnego klienta GG
Group:		Applications/Internet
License:	GPLv3+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description import_history
Importhistory allows you to fetch history from original Gadu-Gadu client. 
Since it has not been reliably tested yet, it's good to make a copy of your 
Kadu actual history. Be aware of repeatedly import of the same history as 
the entries will be multiplied!

%description import_history -l pl
Wtyczka import_history pozwala w chwili obecnej na import historii z wszystkich 
oryginalnych klientów GG. Ponieważ nie została jeszcze solidnie przetestowana, 
przed wykonaniem importu zalecam stworzenie kopii historii kadu. Należy również 
pamiętać o tym, że wielokrotne importowanie tej samej historii powoduje 
powielanie wpisów w historii kadu.

%package kadu_completion
Summary:	Bash completion-like module for Kadu 
Summary(pl):	Dopełnianie podobne do bash completion dla Kadu 
Group:		Applications/Internet
License:	GPLv2+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description kadu_completion
Bash completion-like module for Kadu

%description kadu_completion -l pl
Dopełnianie podobne do bash completion dla Kadu

%package lednotify
Summary:	Notification by Scroll Lock LED
Summary(pl):	Powiadamianie diodą Scroll Lock
Group:		Applications/Internet
License:	GPLv2+
Requires:	%{name}%{?_isa} = %{version}-%{release}
Obsoletes:	%{name}-led_notify < 0.10.1-1

%description lednotify
Led_notify is a module for Kadu, to notify user of some events using Scroll Lock
LED.

%description lednotify -l pl
Led_notify to moduł dla Kadu umożliwiający powiadamianie użytkownika o pewnych
zdarzenia przy użyciu diody Scroll Lock.


%package messagessplitter
Summary:	Automatically splitting too long messages
Summary(pl):	Automatycznie dzieli za długie wiadomości
Group:		Applications/Internet
License:	GPLv3+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description messagessplitter
This extension automatically splits too long messages. Brings the same
functionality as an old module split_messages.

%description messagessplitter -l pl
Wtyczka automatycznie dzieli za długie wiadomości. Dostarcza podobną 
funkcjonalność co stary moduł split_messages.

%package mime_tex
Summary:	TeX formulas support in Kadu
Summary(pl):	Obsługa formuł matematycznych TeX w Kadu
Group:		Applications/Internet
License:	GPLv2+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description mime_tex
Mime_tex is a module for Kadu to edit TeX mathematic formulas in chat window.

%description mime_tex -l pl
Mime_tex to moduł dla Kadu umożliwiający edycję formuł matematycznych TeX
w oknie rozmowy.

%package networkping
Summary:	Automatically reconnects when connection is lost
Summary(pl):	Automatyczne rozłączanie i wznawianie połączenia z serwerem
Group:		Applications/Internet
License:	GPLv3+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description networkping
This extension frequently pings server in order to reconnect when it's needed.

%description networkping -l pl
Wtyczka sprawdza okresowo dostępność sieci i automatycznie rozłącza i wznawia 
połączenia z serwerami protokołów.

%package nextinfo
Summary:	Allows to save more information about your contacts
Summary(pl):	Pozwala na zapisanie dodatkowych informacji o znajomych
Group:		Applications/Internet
License:	GPLv3+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description nextinfo
Nextinfo adds a possibility to store more information about your friends.
Before the same functionality was offered by ext_info module.

%description nextinfo -l pl
Wtyczka dodaje do Kadu możliwość przechowywania dodatkowych informacji 
o znajomych. Wcześniej taką funkcjonalność zapewniał moduł ext_info, 
na którym częściowo wzorowane jest NextInfo.


%package panelkadu
Summary:	Makes a panel from Kadu main window
Summary(pl):	Zamienia Kadu w panel na skraju ekranu
Group:		Applications/Internet
License:	GPLv3+
Requires:	%{name}%{?_isa} = %{version}-%{release}
BuildRequires:	libXtst-devel

%description panelkadu
Panelkadu is a module to make a panel from Kadu main window.

%description panelkadu -l pl
Panelkadu to moduł zamieniający Kadu w panel na skraju ekranu.

%package senthistory
Summary:	History of sent messages in chat windows
Summary(pl):	Historia wysłanych wiadomości w oknie rozmowy
Group:		Applications/Internet
License:	GPLv3+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description senthistory
Senthistory is a module which adds history of sent messages to
chat windows in Kadu.

%description senthistory -l pl
Senthistory to moduł, który dodaje historię wysłanych wiadomości
do okien rozmowy w Kadu.

%package devel
Summary:	Header files for development of kadu
Summary(pl):	Pliki nagłówkowe wymagane do rozwijania kadu
Group:		Applications/Internet
License:	GPLv3+
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
A set of header files for programmers willing to develop kadu.

%description devel -l pl
Zestaw plików nagłówkowych dla programistów chcących rozwijać kadu.

%prep
%setup -q 
%unpack_module_source 117 anonymous_check
%unpack_module_source 102 globalhotkeys
%unpack_module_source 200 import_history
%unpack_module_source 205 kadu_completion
%unpack_module_source 104 lednotify
%unpack_module_source 203 messagessplitter
%unpack_module_source 112 mime_tex
%unpack_module_source 201 networkping
%unpack_module_source 202 nextinfo
%unpack_module_source 114 panelkadu
%unpack_module_source 204 senthistory
%setup -q -D -T

#amarok 1.x is long gone, don't build it
sed '/amarok1_mediaplayer/d' -i Plugins.cmake
# No falf player either
sed '/falf_mediaplayer/d' -i Plugins.cmake
# Neither mpris player is available in fedora
sed '/mprisplayer_mediaplayer/d' -i Plugins.cmake

#let's not annoy users with update notifies
#and disable them

pushd kadu-core
sed "/CheckUpdates/s#true#false#" -i core/core.cpp
popd

# force the right lib path and set DETAILED_VERSION
sed 's#set (LIBDIR ${CMAKE_INSTALL_PREFIX}/lib)#set (LIBDIR %{_libdir})#' -i CMakeLists.txt
sed 's@#define DETAILED.*@#define DETAILED_VERSION "%{name}-%{version}-%{release}"@' -i kadu-config.h.cmake

rm -rf plugins/jabber_protocol/3rdparty
sed -i '/jabber_protocol/D' Plugins.cmake

%build
%{cmake} -DCMAKE_BUILD_TYPE=Debug -DCMAKE_USE_PTHREADS:BOOL=ON -DBUILD_DESCRIPTION="Fedora" .
make VERBOSE=1 %{?_smp_mflags}


%install
make install DESTDIR=$RPM_BUILD_ROOT
desktop-file-install --vendor fedora --delete-original \
    --dir ${RPM_BUILD_ROOT}%{_datadir}/applications	\
    $RPM_BUILD_ROOT%{_datadir}/applications/kadu.desktop
rm -rf $RPM_BUILD_ROOT/usr/sdk

# internal modules:
%find_lang %{name} %{name}.files --with-qt
pushd $RPM_BUILD_ROOT/%{_datadir}/%{name}/translations
for l in *.language;
do echo '%lang('${l%%.*}')' %{_datadir}/%{name}/translations/$l >> %{_builddir}/%{name}-%{version}/%{name}.files;
done
popd

%module_files antistring -cd
%module_files auto_hide -c
%module_files autoaway -c
%module_files autoresponder -c
%module_files autostatus -c
%module_files cenzor -cd
%module_files chat_notify 
%module_files config_wizard 
%module_files desktop_docking -c
%module_files docking -c
%module_files encryption_ng 
cat <<EOF >>encryption_ng.files
%{_datadir}/kadu/plugins/configuration/encryption-ng.ui
EOF
%module_files encryption_ng_simlite
%module_files exec_notify 
%module_files ext_sound -c
%module_files filedesc -c
%module_files firewall -c
%module_files freedesktop_notify -c
%module_files gadu_protocol -d
%module_files hints -c
cat <<EOF >>hints.files
%{_datadir}/kadu/plugins/configuration/hint-over-user.ui
%{_datadir}/kadu/plugins/configuration/hints-advanced.ui
%{_datadir}/kadu/plugins/configuration/hints-notifier.ui
EOF
%module_files history -c
%module_files history_migration
%module_files idle
%module_files imagelink 
cat <<EOF >>imagelink.files
%{_datadir}/kadu/plugins/configuration/image-link.ui
EOF
%module_files last_seen 
%module_files mediaplayer -cd
%module_files mpd_mediaplayer 
cat <<EOF >>mpd_mediaplayer.files
%{_datadir}/kadu/plugins/configuration/mpd_config.ui
EOF
%module_files pcspeaker 
%module_files phonon_sound
%module_files profiles_import 
%module_files qt4_docking
%module_files qt4_docking_notify 
cat <<EOF >>qt4_docking_notify.files
%{_datadir}/kadu/plugins/configuration/qt4-docking-notify.ui
EOF
%module_files qt4_sound 
%module_files screenshot -c
%module_files simpleview -c
%module_files single_window -c
%module_files sms -cd
%module_files sound -c
%module_files speech -c
%module_files spellchecker -c
%module_files sql_history -d
%module_files tabs -c
%module_files word_fix -cd

cat *.files > core.files

# external modules:

%module_files anonymous_check 
%module_files globalhotkeys -c
%module_files import_history 
%module_files kadu_completion -d
%module_files lednotify -c
%module_files messagessplitter -c
%module_files mime_tex -cd
%module_files networkping -c
%module_files nextinfo -c
%module_files panelkadu -c
%module_files senthistory -c

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files -f core.files
%doc COPYING
%{_bindir}/kadu
%{_datadir}/applications/fedora-kadu.desktop
%dir %{_libdir}/kadu
%dir %{_libdir}/kadu/plugins
%dir %{_datadir}/kadu
%{_datadir}/kadu/syntax
%{_datadir}/kadu/AUTHORS
%{_datadir}/kadu/ChangeLog
%{_datadir}/kadu/COPYING
%{_datadir}/kadu/HISTORY
%{_datadir}/kadu/README
%{_datadir}/kadu/THANKS
%{_datadir}/kadu/configuration
%dir %{_datadir}/kadu/plugins
%dir %{_datadir}/kadu/plugins/configuration
%dir %{_datadir}/kadu/plugins/data
%dir %{_datadir}/kadu/plugins/translations
%{_datadir}/kadu/themes
%dir %{_datadir}/kadu/translations
%{_datadir}/icons/hicolor/*/apps/kadu.png
%{_datadir}/kadu/scripts


# devel module:
%files devel
%dir %{_includedir}/kadu
%{_includedir}/kadu/kadu-core/
%{_includedir}/kadu/plugins/
%{_datadir}/kadu/ChangeLog.OLD-PL
%{_datadir}/cmake/Modules/FindKadu.cmake

# external modules:

%files anonymous_check -f anonymous_check.files

%files globalhotkeys -f globalhotkeys.files

%files import_history -f import_history.files

%files kadu_completion -f kadu_completion.files

%files lednotify -f lednotify.files

%files messagessplitter -f messagessplitter.files

%files mime_tex -f mime_tex.files
%{_libdir}/kadu/plugins/bin/mime_tex/mimetex

%files networkping -f networkping.files

%files nextinfo -f nextinfo.files

%files panelkadu -f panelkadu.files

%files senthistory -f senthistory.files

%changelog
* Sun Oct 28 2012 Karol Trzcionka <karlik at fedoraproject.org> - 0.12.2-2
- General cleanup
- Use %%find_lang macro
- Disabling jabber_protocol due to libiris bundle

* Sun Oct 07 2012 Karol Trzcionka <karlik at fedoraproject.org> - 0.12.2-1
- Update to v0.12.2
- Drop --with=opt parameter

* Sat Jan 07 2012 Radoslaw Lisowski <radoslaw.lisowski@gmail.com> - 0.10.1-2
- Provides/Obsoletes problem fix

* Tue Jan 03 2012 Radoslaw Lisowski <radoslaw.lisowski@gmail.com> - 0.10.1-1
- Upgrade to 0.10.1 version of Kadu
- Cleaning up most of mess in kadu.spec file
- Rewriting Provides/Obsoletes
- Dropping falf_mediaplayer and mprisplayer_mediaplayer module

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.5.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Sep 02 2010 Rakesh Pandit <rakesh@fedoraproject.org> - 0.6.5.4-5
- Bump for libao

* Sun Aug 15 2010 Radoslaw Lisowski <radoslaw.lisowski@gmail.com> - 0.6.5.4-4
- fixing build problem with qt4-webkit-devel for f-14+

* Sun Mar 28 2010 Radoslaw Lisowski <radoslaw.lisowski@gmail.com> - 0.6.5.4-3
- Fixed URL address to plus_pl_sms module package
- Fixed modules descriptions and packages
- Removed if ... endif clauses around subpackages definitions
- Added license tags to modules: GPLv2: anonymous_check, led_notify, 
  mail, mime_text, plus_pl_sms, tabs ; GPLv3+: senthistory.

* Tue Mar 23 2010 Julian Sikorski <belegdol@fedoraproject.org> - 0.6.5.4-2
- Dropped separate sources for powerkadu, split_messages and osd_hints modules -
  they are now part of the main tarball
- Updated tabs module to 1.2.7
- Drop shipping the desktop file separately
- Added GPLv3+ License tag to panelkadu and globalhotkeys
- Dropped conditionals around subpackage definitions
- Added now explicitly needed ldflags

* Thu Mar 18 2010 Julian Sikorski <belegdol@fedoraproject.org> - 0.6.5.4-1
- Updated kadu to 0.6.5.4
- Updated modules to their latest versions
- Changed license tag to GPLv2+
- Dropped profiles and gcc44 patches
- BR enchant-devel instead of aspell-devel
- Updated the desktop file
- Added patch from SVN fixing compilation on Fedora >= 13
- Patched bogus module install paths
- Bumped BR'd libgadu version
- Dropped unnecessary %%install kludge
- Re-enabled mediaplayer module
- Dropped amarok1_mediaplayer module
- Enabled amarok2_mediaplayer and audacious_mediaplayer modules

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 0.6.5.2-3
- rebuilt with new openssl

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri May 08 2009 Dawid Gajownik <gajownik[AT]gmail.com> - 0.6.5.2-1
- Update to 0.6.5.2
- Update kadu-gcc44.patch
- Added BuildRequires qca2-devel and libXScrnSaver-devel
- Updated globalhotkeys, mime_tex, osd_hints, panelkadu, powerkadu,
  senthistory and tabs modules
- Package idle and gg_avatars modules
- Handle properly icons
- Add kadu-profiles-fix.patch

* Fri Apr 24 2009 Milos Jakubicek <xjakub@fi.muni.cz> - 0.6.5-10
- Fix FTBFS: added kadu-gcc44.patch

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.5-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> - 0.6.5-8
- rebuild with new openssl

* Tue Dec 16 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-7
- Osd_hints tarball was missing in sources

* Tue Dec 16 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-6
- Enable kadu-osd_hints by default

* Tue Dec 16 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-5
- Fix conflicts with kadu-osd_hints and kadu-agent

* Wed Dec 10 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-4
- More cleaning

* Tue Dec 09 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-3
- Fix bz #475629

* Tue Dec 09 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-2
- Fix kadu-0.6.5 bug and install sounds to proper directory

* Wed Dec 03 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-1
- 0.6.5
- Lots of changes:
-    some modules are now considered default,
-    some others are disabled,
-    some no longer exists,
-    some changed name,
- Parameter "--with=opt" given to rpmbuild makes kadu build to
  /opt instead of /usr (useful feature in testing)
- Kadu now uses qt4
- Lots of Obsoletes/Provides to prevent breaking updates
- Etc.

* Mon May 19 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0.1-1
- 0.6.0.1
- New version of mime_tex, tabs, firewall, osd_hints, powerkadu,
audacious_mediaplayer
- New url of ao_sound
- New modules: autostatus, last_seen, globalhotkeys
- Panelkadu requires libXtst-devel to build

* Tue Apr 01 2008 Rex Dieter <rdieter@fedoraproject.org> - 0.6.0-3
- -devel: qt3-devel (f9+)

* Wed Mar 12 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-2
- Fix bugs 436574 (f8) and 436575 (f7)
- New versions of tabs and osd_hints
- New modules: anonymous_check antistring auto_hide cenzor parser_extender 
powerkadu split_messages word_fix


* Thu Feb 28 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-1
- Stable
- New versions of osd_hints, audacious_mediaplayer, filtering,
mediaplayer and panelkadu

* Mon Feb 18 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.12.rc4
- rc4
- Add modules: water_notify, osd_hints, panelkadu

* Wed Feb 13 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.11.rc3
- rc3
- New firewall module
- New versions of some modules

* Sun Feb 03 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.10.rc2.try2
- rc2-try2

* Sun Feb 03 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.9.rc2
- rc2
- New versions of led_notify, weather, pcspeaker, mime_tex, tabs,
mediaplayer, xmms_mediaplayer and mail modules
- Add filtering module
- Get rid of xmmsfix patch
- Fix mail module

* Sun Jan 13 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.8.rc1
- rc1
- New mx610_notify, falf_mediaplayer, mail and mime_tex modules.
- New versions of some modules

* Sun Jan 06 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.7.beta2
- Fix bug 427679 (add forgotten %% symbol in one place)

* Sun Jan 06 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.6.beta2
- Now forgot to include that one source changed its name

* Sun Jan 06 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.5.beta2
- Forgot to upload some sources...

* Sat Jan 05 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.4.beta2
- beta2
- Add kadu-agent

* Fri Dec 21 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.3.beta1
- 0.6.0-beta1
- Changes of almost everything, spec file has been completely rewritten
- Get rid of stupid macros including %%{_kadudir} and %%{_modtrans}
- Make it possible to build any subpackages whoever wants, no need to build
all
- Add Polish descriptions to all subpackages and change English ones
- There are too many changes to list all of them ;-)
- Hope it's now much more readable and user-friendly

* Wed Dec 19 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.2.alpha2
- 0.6.0-alpha2
- New pcspeaker module
- New version of miastoplusa_sms, profiles, dcopexport

* Sat Dec 01 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.1.alpha1
- 0.6.0-alpha1
- remove xmms, amarok, mail, extinfo, iwait4u, powerkadu, advanced_userlist, osd_hints, screenshot, firewall, filedesc
- update spellchecker, weather, dcopexport, miastopolusa_sms, tabs, led_notify, filtering
- get rid of tabs patch
- add filedesc, spellchecker and firewall patches
- exec_notify is now built-in

* Fri Aug 24 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-4
- Fix desktop file

* Fri Aug 24 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-3
- BuildID rebuild
- Fix License tag

* Thu Apr 05 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-2
- Own %%{_datadir}/kadu/modules/data (BZ: 233855)

* Tue Jan 02 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-1
- Finally a stable release

* Mon Dec 25 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.21.rc2
- Bump to RC2

* Mon Nov 14 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.20.rc1
- Add advanced_userlist, osd_hints and screenshot modules

* Wed Nov 08 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.19.rc1
- Update kadu to RC1
- Update ext_info module to 2.0beta9
- Update powerkadu module to 20061026
- Update xmms module to 1.32
- Update amarok module to 1.19
- Amarok builds on all architectures again
- Add tabs patch

* Thu Nov 02 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.18.20060915svn
- Come back to 20060915

* Sun Oct 29 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.17.20061029svn
- Disabling kadu-amarok on ppc arch

* Sun Oct 29 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.16.20061029svn
- Bump cvs snapshot to 20061029

* Tue Oct 10 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.15.20060915svn
- Another fix to not rebuilding kadu-amarok

* Sat Oct 07 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.14.20060915svn
- It really shoud work now

* Sat Oct 07 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.13.20060915svn
- It should work now

* Fri Oct 06 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.12.20060915svn
- Yet another fix...

* Fri Oct 06 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.11.20060915svn
- Rpmbuild build error workaround.

* Fri Oct 06 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.10.20060915svn
- Not rebuilding kadu-amarok on some archs

* Sat Sep 16 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.9.20060915svn
- Update upstream to 20060915
- Move themes to external spec file
- Link to existing libgadu

* Mon Sep 04 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.8.20006808svn
- FC6 rebuild

* Fri Aug 11 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.7.20060808svn
- Update upstream to 20060808
- Add firewall and wmaker_docking modules

* Sun Jul 30 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.6.20060730svn
- Update upstream do 20060730, with fixed x64 bugs
- Add mail module and emots theme

* Thu Jul 27 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.5.20060727svn
- Delete qt dependency
- Exclude libgadu.a file
- Add powerkadu, filtering and profiles modules

* Mon Jul 24 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.4.20060716svn
- Add COPYING file to doc

* Sun Jul 23 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.3.20060716svn
- Yet another fix permissions of .so files

* Sun Jul 23 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.2.20060716svn
- Fix Source0 address
- Fix permissions of .so files
- Remove libsndfile require
- Fix some descriptions of subpackages
- Add --enable-debug and --disable-dependency-tracking options to configure

* Thu Jul 20 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.1.20060716svn
- Another first release


